@@ -59,10 +59,11 @@ qx.Class.define("callbackery.Application", {
                     qx.Theme.define('callbackery.theme.CustomColor',{
                         colors: baseCfg.COLORS
                     });
-                    qx.Theme.patch(callbackery.theme.Color,callbackery.theme.CustomColor);
+                    var colorTheme = qx.theme.manager.Color.getInstance().getTheme();
+                    qx.Theme.patch(colorTheme,callbackery.theme.CustomColor);
                     // reset/set theme to get the changes visible in to ui
                     qx.theme.manager.Color.getInstance().resetTheme();
-                    qx.theme.manager.Color.getInstance().setTheme(callbackery.theme.Color);
+                    qx.theme.manager.Color.getInstance().setTheme(colorTheme);
                 }
                 rpc.callAsyncSmart(function(userCfg){
                     callbackery.data.Config.getInstance().setUserConfig(userCfg);
